;;  ByLayer.lsp [command names: BYce, BYs, BYall, BYevery]
;;  To change all properties of objects to BYLAYER and other defaults,
;;    clearing out all entity-specific overrides on such properties.
;;  Works on top-level entities only, not nested ones [e.g. in Blocks].
;;  Kent Cooper, 12 March 2013

(defun C:BYce (); = Current-Entity settings to BYLAYER and other defaults
  (setvar 'cecolor "BYLAYER")
  (setvar 'celtype "BYLAYER")
  (setvar 'celtscale 1.0)
  (setvar 'celweight -1)
  (setvar 'thickness 0.0)
); defun

(defun C:BYs (/ ss cmde) ; of User-Selected item(s)
  (setq
    ss (cond ((ssget "_I")) ((ssget))); ask User if nothing pre-selected
    cmde (getvar 'cmdecho)
  ); setq
  (if ss
    (progn
      (setvar 'cmdecho 0)
      (sssetfirst nil); clears pre-selection [if any] to avoid object-selection problem
      (command "_.chprop" ss ""
        "_color" "BYLAYER" "_ltype" "BYLAYER" "_ltScale" 1
        "_LWeight" "BYLAYER" "_Thickness" 0 ""
      ); command
      (setvar 'cmdecho cmde)
    ); progn
  ); if
  (C:BYce)
  (princ)
); defun

(defun C:BYall (/ cmde) ; of ALL item(s) in current space
  (setq cmde (getvar 'cmdecho))
  (setvar 'cmdecho 0)
  (sssetfirst nil); clears pre-selection [if any] to avoid object-selection problem
  (command
    "_.chprop" "_all" "" "_color" "BYLAYER" "_ltype" "BYLAYER"
      "_ltScale" 1 "_LWeight" "BYLAYER" "_Thickness" 0 ""
  ); command
  (setvar 'cmdecho cmde)
  (C:BYce)
  (princ)
); defun

(defun C:BYevery (/ ss) ; of EVERYthing in drawing, in all spaces
  (setq ss (ssget "_X"))
  (repeat (sslength ss)
    (setq
      ent (ssname ss 0)
      edata (entget ent)
      edata (subst '(62 . 256) (assoc 62 edata) edata); color
      edata (subst '(6 . "BYLAYER") (assoc 6 edata) edata); linetype
      edata (subst '(48 . 1.0) (assoc 48 edata) edata); linetype scale
      edata (subst '(370 . -1) (assoc 370 edata) edata); lineweight
      edata (subst '(39 . 0.0) (assoc 39 edata) edata); thickness
    ); setq
    (entmod edata)
    (ssdel ent ss)
  ); repeat
  (C:BYce)
  (princ)
); defun